%define gettext_package gnome-terminal

%define glib2_version 2.16.0
%define gtk2_version 2.14.0
%define gconf_version 2.14.0
%define vte_version 0.25.1
%define desktop_file_utils_version 0.2.90

Summary: Terminal emulator for GNOME
Name: gnome-terminal
Version: 2.31.3
Release: 8%{?dist}
License: GPLv2+ and GFDL
Group: User Interface/Desktops
URL: http://www.gnome.org/
Source0: http://download.gnome.org/sources/gnome-terminal/2.31/gnome-terminal-%{version}.tar.bz2
# http://bugzilla.gnome.org/show_bug.cgi?id=588732
Source1: profile-new-dialog.ui
# Fix gnome.org Bug 338913 – Terminal resized when switching tabs
Patch2: gnome-terminal-2.15.0-338913-revert-336325.patch

# make docs show up in rarian/yelp
Patch3: gnome-terminal-doc-category.patch

# drop gtk requirement down again
Patch4: gnome-terminal-unseal.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=604207
Patch5: gnome-terminal-tab-dnd-fix.patch

# Translation update
# https://bugzilla.redhat.com/show_bug.cgi?id=575706
Patch6: gnome-terminal-2.31.3-translations.patch

# searchable scroll back in gnome-terminal does not work as expected
# https://bugzilla.redhat.com/show_bug.cgi?id=669113
Patch7: gnome-terminal-2.33.4-search-regexp.patch

# URLs with a colon in them are not interpreted correctly for Open Link
# https://bugzilla.redhat.com/show_bug.cgi?id=655132
Patch8: gnome-terminal-urls-with-colons.patch

# [ALL_LANG] Translation tracker for gnome-terminal
# https://bugzilla.redhat.com/show_bug.cgi?id=819796
Patch9: gnome-terminal-bz-819796-trans.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# gconftool-2
Requires(pre): GConf2 >= %{gconf_version}
Requires(post): GConf2 >= %{gconf_version}
Requires(preun): GConf2 >= %{gconf_version}
Requires(post): scrollkeeper
Requires(postun): scrollkeeper

# needed for GConf schemas
Requires: libgnome

BuildRequires: glib2-devel >= %{glib2_version}
BuildRequires: gtk2-devel >= %{gtk2_version}
BuildRequires: GConf2-devel >= %{gconf_version}
BuildRequires: libglade2-devel
BuildRequires: libgnomeui-devel
BuildRequires: vte-devel >= %{vte_version}
BuildRequires: desktop-file-utils >= %{desktop_file_utils_version}
BuildRequires: scrollkeeper
BuildRequires: gettext
BuildRequires: gnome-doc-utils
BuildRequires: intltool


%description
gnome-terminal is a terminal emulator for GNOME. It supports translucent
backgrounds, opening multiple terminals in a single window (tabs) and
clickable URLs.

%prep
%setup -q
%patch2 -p1 -b .338913-revert-336325
%patch3 -p1 -b .doc-category
%patch4 -p1 -R -b .unseal
%patch5 -p1 -b .tab-dnd-fix
%patch6 -p2 -b .translations
%patch7 -p1 -b .search-regexp
%patch8 -p1 -b .urls-with-colons
%patch9 -p2 -b .translations2

%build

#workaround broken perl-XML-Parser on 64bit arches
export PERL5LIB=/usr/lib64/perl5/vendor_perl/5.8.2 perl

%configure --with-widget=vte --disable-scrollkeeper
make %{?_smp_mflags}

cp %{SOURCE1} src

# strip unneeded translations from .mo files
cd po
grep -v ".*[.]desktop[.]in.*\|.*[.]server[.]in$" POTFILES.in > POTFILES.keep
mv POTFILES.keep POTFILES.in
intltool-update --pot
PO_FAKE_DATE="2009-08-03 18:00+0200"   # fake this to be equal in every build
PO_FAKE_DATE_EXPR='\(.*POT-Creation-Date: *\)\(.*\)\(\\n.*\)'
sed --in-place "s/${PO_FAKE_DATE_EXPR}/\1${PO_FAKE_DATE}\3/" %{gettext_package}.pot
for p in *.po; do
  msgmerge $p %{gettext_package}.pot > $p.out
  msgfmt -o `basename $p .po`.gmo $p.out
done

%install
rm -rf $RPM_BUILD_ROOT

export GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL=1
make install DESTDIR=$RPM_BUILD_ROOT
unset GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL

sed -i -e "s/Icon=gnome-terminal.png/Icon=gnome-terminal/" \
  $RPM_BUILD_ROOT%{_datadir}/applications/gnome-terminal.desktop

desktop-file-install --vendor gnome --delete-original	\
  --dir $RPM_BUILD_ROOT%{_datadir}/applications		\
  --remove-category=Application				\
  --add-category=System					\
  $RPM_BUILD_ROOT%{_datadir}/applications/gnome-terminal.desktop

# grr, --disable-scrollkeeper is not good enough
rm -rf $RPM_BUILD_ROOT/var/scrollkeeper

%find_lang %{gettext_package} --with-gnome

%clean
rm -rf $RPM_BUILD_ROOT

%post
scrollkeeper-update -q
export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
gconftool-2 --makefile-install-rule \
	%{_sysconfdir}/gconf/schemas/gnome-terminal.schemas > /dev/null || :

%pre
if [ "$1" -gt 1 ]; then
    export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
    gconftool-2 --makefile-uninstall-rule \
      %{_sysconfdir}/gconf/schemas/gnome-terminal.schemas > /dev/null || :
fi

%preun
if [ "$1" -eq 0 ]; then
    export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
    gconftool-2 --makefile-uninstall-rule \
      %{_sysconfdir}/gconf/schemas/gnome-terminal.schemas > /dev/null || :
fi

%postun
scrollkeeper-update -q

%files -f %{gettext_package}.lang
%defattr(-,root,root,-)

%doc AUTHORS COPYING NEWS README

%{_bindir}/gnome-terminal
%{_datadir}/gnome-terminal
%{_datadir}/omf/gnome-terminal
%{_datadir}/applications/gnome-terminal.desktop
%{_sysconfdir}/gconf/schemas/gnome-terminal.schemas


%changelog

